@@ -3,16 +3,19 @@ from ..module import Module
 
 class RestoreBackupModule(Module):
     def process(self):
-        self.restoreBackup()
+        Module.restoreBackup()
 
+    @staticmethod
     def getFlag():
         return "rb"
 
+    @staticmethod
     def getName():
         return "Restore Backup"
 
+    @staticmethod
     def getDescription():
         return ""
 
     def isVisible(self):
-        return self.hasBackup()
+        return Module.hasBackup()
