@@ -1,10 +1,12 @@
-from datetime import datetime
 from ..module import Module
+from datetime import datetime
+from ..utils.loading import Loading
+from gitools.utils.utilities import Utilities
 
 
 class UpdateDateModule(Module):
     def process(self):
-        self.checkBackup()
+        Module.checkBackup()
         self.selectCommit()
 
         if not self.commit_date:
@@ -12,7 +14,7 @@ class UpdateDateModule(Module):
                 (commit for commit in self.commits if commit[0] == self.commit_hash),
                 None,
             )
-            date = self.input(
+            date = Module.input(
                 "Fri Jan 1 00:00:00 2021 +0000"
                 if old_commit_date is None
                 else old_commit_date[4]
@@ -33,6 +35,9 @@ class UpdateDateModule(Module):
             self.process()
             return
 
+        Utilities.clearConsole()
+        loading = Loading("Please wait")
+
         command = """git filter-branch -f --env-filter 'if [ $GIT_COMMIT = "COMMIT_HASH" ]
                 then
                     export GIT_AUTHOR_DATE="NEW_DATE";
@@ -45,17 +50,23 @@ class UpdateDateModule(Module):
 
         _, err = self.excuteCommand(command)
 
+        loading.stop()
+        Utilities.clearConsole()
+
         if not err:
             print("Date Changed Successfully")
         else:
             print("Date Change Failed, Error:\r\n" + err.decode("utf-8"))
 
+    @staticmethod
     def getFlag():
         return "ud"
 
+    @staticmethod
     def getName():
         return "Update Date"
 
+    @staticmethod
     def getDescription():
         return "Update commit date time"
 
