@@ -1,9 +1,11 @@
 from ..module import Module
+from ..utils.loading import Loading
+from gitools.utils.utilities import Utilities
 
 
 class UpdateMessageModule(Module):
     def process(self):
-        self.checkBackup()
+        Module.checkBackup()
         self.selectCommit()
 
         if not self.commit_message:
@@ -11,10 +13,13 @@ class UpdateMessageModule(Module):
                 (commit for commit in self.commits if commit[0] == self.commit_hash),
                 None,
             )
-            self.commit_message = self.input(
+            self.commit_message = Module.input(
                 "# Enter New Commit Message" if old_message is None else old_message[5]
             ).replace("# Enter New Commit Message", "")
 
+        Utilities.clearConsole()
+        loading = Loading("Please wait")
+
         command = """git filter-branch --msg-filter 'if [[ $GIT_COMMIT = "COMMIT_HASH" ]]
                     then
                         echo "NEW_MESSAGE"
@@ -28,17 +33,23 @@ class UpdateMessageModule(Module):
 
         _, err = self.excuteCommand(command)
 
+        loading.stop()
+        Utilities.clearConsole()
+
         if not err:
             print("Commit Message Changed Successfully")
         else:
             print("Commit Message Change Failed, Error:\r\n" + err.decode("utf-8"))
 
+    @staticmethod
     def getFlag():
         return "um"
 
+    @staticmethod
     def getName():
         return "Update Message"
 
+    @staticmethod
     def getDescription():
         return "Update commit message"
 
